| Title: | Check Validity of Greek AFM and PA Numbers |
|---|---|
| Description: | With the functions in this package you can check the validity of the Greek Tax Identification Number (AFM) and the Greek Personal Number (PA) <https://pa.gov.gr>. The PA is a new universal ID for Greek citizens across all public services and it is to replace older numbers issued by various Greek state agencies. Its format is a 12-character ID consisting of three alphanumeric characters followed by the nine numerical digits of the AFM. |
| Authors: | Panagiotis Cheilaris [aut, cre] |
| Maintainer: | Panagiotis Cheilaris <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.2.0 |
| Built: | 2026-05-27 09:11:21 UTC |
| Source: | https://github.com/philaris/afmpar |
Given a character vector, for each of its elements, check the validity of the Greek Tax Identification Number (AFM).
afm_check(v)afm_check(v)
v |
a character vector for whose elements validity of AFM is checked. |
A logical vector.
afm_check("BADAFM999") afm_check("123456789") afm_check("12345678") afm_check("123456783") afm_check(c("123456789", "111111116"))afm_check("BADAFM999") afm_check("123456789") afm_check("12345678") afm_check("123456783") afm_check(c("123456789", "111111116"))
Given a character vector, for each of its elements, check the validity of the Greek Personal Number (PA). The PA allows numeric digits 0-9 and the uppercase Latin letters whose uppercase glyphs are the same in the Greek and Latin alphabet (ABEZHIKMNOPTYX).
pa_check(v)pa_check(v)
v |
a character vector for whose elements validity of PA is checked. |
A logical vector.
pa_check("ABYBADAFM999") pa_check("ABY123456789") pa_check("ABY12345678") pa_check("ABY1234567890") pa_check("5XY123456783") pa_check(c("ABY123456789", "PTT111111114"))pa_check("ABYBADAFM999") pa_check("ABY123456789") pa_check("ABY12345678") pa_check("ABY1234567890") pa_check("5XY123456783") pa_check(c("ABY123456789", "PTT111111114"))